@@ -147,12 +147,11 @@ std::string AppendSerializationFormat(const std::string &base) {
 
 std::string GetCachePath(std::string src) {
   if (g_config->cache.hierarchicalPath) {
-    std::string ret =
-        g_config->cache.directory + (src[0] == '/' ? src.substr(1) : src);
+    std::string ret = src[0] == '/' ? src.substr(1) : src;
 #ifdef _WIN32
     std::replace(ret.begin(), ret.end(), ':', '@');
 #endif
-    return ret;
+    return g_config->cache.directory + ret;
   }
   for (auto &[root, _] : g_config->workspaceFolders)
     if (StringRef(src).startswith(root)) {
